@@ -15,6 +15,9 @@
 This module is used for Pyramid integration
 """
 
+from pyams_security_views.interfaces import REST_PRINCIPALS_SEARCH_ROUTE
+
+
 __docformat__ = 'restructuredtext'
 
 
@@ -24,6 +27,11 @@ def include_package(config):
     # add translations
     config.add_translation_dirs('pyams_security_views:locales')
 
+    # register new REST API routes
+    config.add_route(REST_PRINCIPALS_SEARCH_ROUTE,
+                     config.registry.settings.get('pyams.security.rest_principals_route',
+                                                  '/api/security/principals'))
+
     try:
         import pyams_zmi  # pylint: disable=import-outside-toplevel,unused-import
     except ImportError:
